@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 from __future__ import unicode_literals
 
-VERSION = "1.14.1"
+VERSION = "1.15.0"
 
 import curses
 from datetime import datetime, timedelta
@@ -280,6 +280,7 @@ def countdown(
     title=None,
     voice=None,
     voice_prefix=None,
+    exec_cmd=None,
     outfile=None,
     no_bell=False,
     no_seconds=False,
@@ -309,6 +310,7 @@ def countdown(
             if os.path.exists(cmd):
                 voice_cmd = cmd
                 break
+    if voice or exec_cmd:
         voice_prefix = voice_prefix or ""
 
     input_thread = Thread(
@@ -347,19 +349,27 @@ def countdown(
                         )
                     except CharNotPrinted:
                         draw_text(stdscr, "E")
-            if voice_cmd:
-                announciation = None
-                if seconds_left <= critical:
-                    announciation = str(seconds_left)
-                elif seconds_left in (5, 10, 20, 30, 60):
-                    announciation = "{} {} seconds".format(voice_prefix, seconds_left)
-                elif seconds_left in (300, 600, 1800):
-                    announciation = "{} {} minutes".format(voice_prefix, int(seconds_left / 60))
-                elif seconds_left == 3600:
-                    announciation = "{} one hour".format(voice_prefix)
-                if announciation:
+            annunciation = None
+            if seconds_left <= critical:
+                annunciation = str(seconds_left)
+            elif seconds_left in (5, 10, 20, 30, 60):
+                annunciation = "{} {} seconds".format(voice_prefix, seconds_left)
+            elif seconds_left in (300, 600, 1800):
+                annunciation = "{} {} minutes".format(voice_prefix, int(seconds_left / 60))
+            elif seconds_left == 3600:
+                annunciation = "{} one hour".format(voice_prefix)
+            if annunciation or exec_cmd:
+                if exec_cmd:
                     Popen(
-                        [voice_cmd, "-v", voice, announciation.strip()],
+                        exec_cmd.format(seconds_left, annunciation or ""),
+                        stdout=DEVNULL,
+                        stderr=STDOUT,
+                        shell=True,
+                    )
+
+                if voice_cmd:
+                    Popen(
+                        [voice_cmd, "-v", voice, annunciation.strip()],
                         stdout=DEVNULL,
                         stderr=STDOUT,
                     )
@@ -396,6 +406,7 @@ def countdown(
                                 countdown_text if no_figlet else figlet.renderText(countdown_text),
                                 color=3,
                                 fallback=countdown_text,
+                                title=title,
                             )
                         except CharNotPrinted:
                             draw_text(stdscr, "E")
@@ -499,6 +510,8 @@ def countdown(
 def stopwatch(
     stdscr,
     alt_format=False,
+    critical=3,
+    exec_cmd=None,
     font=DEFAULT_FONT,
     no_figlet=False,
     no_seconds=False,
@@ -508,6 +521,7 @@ def stopwatch(
     no_window_title=False,
     time=False,
     time_format=None,
+    voice_prefix=None,
     **kwargs
 ):
     curses_lock, input_queue, quit_event = setup(stdscr)
@@ -533,27 +547,46 @@ def stopwatch(
         while quit_after is None or seconds_elapsed < int(quit_after):
             figlet.width = stdscr.getmaxyx()[1]
             if time:
-                countdown_text = datetime.now().strftime(time_format)
+                stopwatch_text = datetime.now().strftime(time_format)
             elif alt_format:
-                countdown_text = format_seconds_alt(seconds_elapsed, 0, hide_seconds=no_seconds)
+                stopwatch_text = format_seconds_alt(seconds_elapsed, 0, hide_seconds=no_seconds)
             else:
-                countdown_text = format_seconds(seconds_elapsed, hide_seconds=no_seconds)
+                stopwatch_text = format_seconds(seconds_elapsed, hide_seconds=no_seconds)
             with curses_lock:
                 if not no_window_title:
-                    os.write(stdout.fileno(), "\033]2;{0}\007".format(countdown_text).encode())
+                    os.write(stdout.fileno(), "\033]2;{0}\007".format(stopwatch_text).encode())
                 if outfile:
                     with open(outfile, 'w') as f:
-                        f.write("{}\n{}\n".format(countdown_text, seconds_elapsed))
+                        f.write("{}\n{}\n".format(stopwatch_text, seconds_elapsed))
                 stdscr.erase()
                 try:
                     draw_text(
                         stdscr,
-                        countdown_text if no_figlet else figlet.renderText(countdown_text),
-                        fallback=countdown_text,
+                        stopwatch_text if no_figlet else figlet.renderText(stopwatch_text),
+                        fallback=stopwatch_text,
                         title=title,
                     )
                 except CharNotPrinted:
                     draw_text(stdscr, "E")
+            if exec_cmd:
+                voice_prefix = voice_prefix or ""
+                annunciation = ""
+                if seconds_elapsed <= critical and seconds_elapsed > 0:
+                    annunciation = str(seconds_elapsed)
+                elif seconds_elapsed in (5, 10, 20, 30, 40, 50, 60):
+                    annunciation = "{} {} seconds".format(voice_prefix, seconds_elapsed)
+                elif seconds_elapsed in (120, 180, 300, 600, 1800):
+                    annunciation = "{} {} minutes".format(voice_prefix, int(seconds_elapsed / 60))
+                elif seconds_elapsed == 3600:
+                    annunciation = "{} one hour".format(voice_prefix)
+                elif seconds_elapsed % 3600 == 0 and seconds_elapsed > 0:
+                    annunciation = "{} {} hours".format(voice_prefix, int(seconds_elapsed / 3600))
+                Popen(
+                    exec_cmd.format(seconds_elapsed, annunciation),
+                    stdout=DEVNULL,
+                    stderr=STDOUT,
+                    shell=True,
+                )
             sleep_target = sync_start + timedelta(seconds=seconds_elapsed + 1)
             if time:
                 sleep_target = sleep_target.replace(microsecond=0)
@@ -567,17 +600,17 @@ def stopwatch(
                     pause_start = datetime.now()
                     with curses_lock:
                         if not no_window_title:
-                            os.write(stdout.fileno(), "\033]2;{0}\007".format(countdown_text).encode())
+                            os.write(stdout.fileno(), "\033]2;{0}\007".format(stopwatch_text).encode())
                         if outfile:
                             with open(outfile, 'w') as f:
-                                f.write("{}\n{}\n".format(countdown_text, seconds_elapsed))
+                                f.write("{}\n{}\n".format(stopwatch_text, seconds_elapsed))
                         stdscr.erase()
                         try:
                             draw_text(
                                 stdscr,
-                                countdown_text if no_figlet else figlet.renderText(countdown_text),
+                                stopwatch_text if no_figlet else figlet.renderText(stopwatch_text),
                                 color=3,
-                                fallback=countdown_text,
+                                fallback=stopwatch_text,
                                 title=title,
                             )
                         except CharNotPrinted:
@@ -640,11 +673,12 @@ def input_thread_body(stdscr, input_queue, quit_event, curses_lock):
 @click.option("-B", "--no-bell", default=False, is_flag=True,
               help="Don't ring terminal bell at end of countdown")
 @click.option("-c", "--critical", default=3, metavar="N",
-              help="Draw final N seconds in red (defaults to 3)")
+              help="Draw final N seconds in red and announce them individually with --voice "
+                   "or --exec-cmd (defaults to 3)")
 @click.option("-f", "--font", default=DEFAULT_FONT, metavar="FONT",
               help="Choose from http://www.figlet.org/examples.html")
 @click.option("-p", "--voice-prefix", metavar="TEXT",
-              help="Add TEXT to the beginning of --voice announciations "
+              help="Add TEXT to the beginning of --voice and --exec annunciations "
                    "(except per-second ones)")
 @click.option("-q", "--quit-after", metavar="N",
               help="Quit N seconds after countdown (use with -b or -t) "
@@ -660,11 +694,16 @@ def input_thread_body(stdscr, input_queue, quit_event, curses_lock):
               help="Don't update terminal title with remaining/elapsed time")
 @click.option("-v", "--voice", metavar="VOICE",
               help="Spoken countdown "
-                   "(at fixed intervals with per-second announciations starting at --critical; "
+                   "(at fixed intervals with per-second annunciations starting at --critical; "
                    "requires `espeak` on Linux or `say` on macOS; "
                    "choose VOICE from `say -v '?'` or `espeak --voices`)")
 @click.option("-o", "--outfile", metavar="PATH", callback=verify_outfile,
               help="File to write current remaining/elapsed time to")
+@click.option("--exec-cmd", metavar="CMD",
+              help="Runs CMD every second. '{0}' and '{1}' in CMD will be replaced with the "
+                   "remaining/elapsed number of seconds and a more sparse annunciation as in "
+                   "--voice, respectively. For example, to get a callout at five seconds only, "
+                   "use: --exec-cmd \"if [ '{0}' == '5' ]; then say -v Alex {1}; fi\"")
 @click.option("--no-figlet", default=False, is_flag=True,
               help="Don't use ASCII art for display")
 @click.option("--no-text-magic", default=False, is_flag=True,
